searchData={"items":[{"type":"module","title":"Datix","doc":"A date-time parser using `Calendar.strftime/3` format strings.","ref":"Datix.html"},{"type":"function","title":"Datix.compile/1","doc":"Compiles the given `format` string.\n\nIf the `format` string is a valid format string, then this function returns\n`{:ok, compiled}`. `compiled` is a term that represents a compiled format (its internal\nrepresentation is private). You can pass a `t:compiled/0` term to `strptime/3` and\nsuch.\n\nIf the `format` string is invalid, this function returns `{:error, reason}`, where\n`reason` is an *exception struct*.\n\nYou can use this function for two reasons:\n\n  * You have the same format string that you want to compile once and then use\n    to parse over and over\n\n  * You want to *validate* a format string","ref":"Datix.html#compile/1"},{"type":"function","title":"Datix.compile!/1","doc":"Like `compile/1`, but returns the compiled struct directly or raises in case of errors.","ref":"Datix.html#compile!/1"},{"type":"function","title":"Examples - Datix.compile!/1","doc":"iex> Datix.compile!(\"%Y-%m-%d\")\n    Datix.compile!(\"%Y-%m-%d\")\n\n    iex> Datix.compile!(\"%l\")\n    ** (Datix.FormatStringError) invalid format string because of invalid modifier: %l","ref":"Datix.html#compile!/1-examples"},{"type":"function","title":"Datix.strptime/3","doc":"Parses a date-time string according to the given `format`.\n\nSee the `Calendar.strftime/3` documentation for how to specify a format string.\n\n`format` can be a format string or, since v0.2.0 of the library,\na **compiled format** as returned by `compile/1`.\n\nIf parsing is successful, this function returns `{:ok, datix}` where `datix` is\na map of type `t:t/0`. If you are looking for functions that return Elixir\nstructs (such as `DateTime` and similar), see `Datix.DateTime`, `Datix.Date`,\n`Datix.Time`, and `Datix.NaiveDateTime`.\n\nIf there's an error, this function returns `{:error, error}` where error\nis an *exception struct*. You can raise it manually with `raise/1`.","ref":"Datix.html#strptime/3"},{"type":"function","title":"Options - Datix.strptime/3","doc":"* `:preferred_date` - a string for the preferred format to show dates,\n    it can't contain the `%x` format and defaults to `\"%Y-%m-%d\"`\n    if the option is not received\n\n  *  `:month_names` - a list of the month names, if the option is not received\n    it defaults to a list of month names in English\n\n  * `:abbreviated_month_names` - a list of abbreviated month names, if the\n    option is not received it defaults to a list of abbreviated month names in\n    English\n\n  * `:day_of_week_names` - a list of day names, if the option is not received\n    it defaults to a list of day names in English\n\n  * `:abbreviated_day_of_week_names` - a list of abbreviated day names, if the\n    option is not received it defaults to a list of abbreviated day names in\n    English\n\n  * `:preferred_time` - a string for the preferred format to show times,\n    it can't contain the `%X` format and defaults to `\"%H:%M:%S\"`\n    if the option is not received\n\n  * `:am_pm_names` - a keyword list with the names of the period of the day,\n    defaults to `[am: \"am\", pm: \"pm\"]`.","ref":"Datix.html#strptime/3-options"},{"type":"function","title":"Examples - Datix.strptime/3","doc":"iex> Datix.strptime(\"2021/01/10\", \"%Y/%m/%d\")\n    {:ok, %{day: 10, month: 1, year: 2021}}\n\n    iex> Datix.strptime(\"21/01/10\", \"%y/%m/%d\")\n    {:ok, %{day: 10, month: 1, year_2_digit: 21}}\n\n    iex> Datix.strptime(\"13/14/15\", \"%H/%M/%S\")\n    {:ok, %{hour: 13, minute: 14, second: 15}}\n\n    iex> Datix.strptime(\"1 PM\", \"%-I %p\")\n    {:ok, %{am_pm: :pm, hour_12: 1}}\n\n    iex> Datix.strptime(\"Tuesday\", \"%A\")\n    {:ok, %{day_of_week: 2}}\n\n    iex> Datix.strptime(\"Tue\", \"%a\")\n    {:ok, %{day_of_week: 2}}\n\n    iex> Datix.strptime(\"Di\", \"%a\",\n    ...>   abbreviated_day_of_week_names: ~w(Mo Di Mi Do Fr Sa So))\n    {:ok, %{day_of_week: 2}}\n\n    iex> compiled = Datix.compile!(\"%Y/%m/%d\")\n    iex> Datix.strptime(\"2021/01/10\", compiled)\n    {:ok, %{day: 10, month: 1, year: 2021}}\n\n    iex> Datix.strptime(\"irrelevant\", \"%l\")\n    {:error, %Datix.FormatStringError{reason: {:invalid_modifier, \"%l\"}}}","ref":"Datix.html#strptime/3-examples"},{"type":"function","title":"Datix.strptime!/3","doc":"Parses a date-time string according to the given `format`, erroring out for\ninvalid arguments.","ref":"Datix.html#strptime!/3"},{"type":"opaque","title":"Datix.compiled/0","doc":"An **opaque** type representing a compiled format.\n\nThe struct representation is internal and could change in the future without notice.","ref":"Datix.html#t:compiled/0"},{"type":"type","title":"Datix.t/0","doc":"","ref":"Datix.html#t:t/0"},{"type":"module","title":"Datix.Date","doc":"A `Date` parser using `Calendar.strftime/3` format strings.","ref":"Datix.Date.html"},{"type":"function","title":"Datix.Date.parse/3","doc":"Parses a date string according to the given `format`.\n\nSee the `Calendar.strftime/3` documentation for how to specify a format-string.","ref":"Datix.Date.html#parse/3"},{"type":"function","title":"Options - Datix.Date.parse/3","doc":"* `:calendar` - the calendar to build the `Date`, defaults to `Calendar.ISO`\n\n  * `:preferred_date` - a string for the preferred format to show dates,\n    it can't contain the `%x` format and defaults to `\"%Y-%m-%d\"`\n    if the option is not received\n\n  *  `:month_names` - a list of the month names, if the option is not received\n    it defaults to a list of month names in English\n\n  * `:abbreviated_month_names` - a list of abbreviated month names, if the\n    option is not received it defaults to a list of abbreviated month names in\n    English\n\n  * `:day_of_week_names` - a list of day names, if the option is not received\n    it defaults to a list of day names in English\n\n  * `:abbreviated_day_of_week_names` - a list of abbreviated day names, if the\n    option is not received it defaults to a list of abbreviated day names in\n    English\n\n  * `:pivot_year` - a 2-digit year that represents the *pivot year* to use when\n    `%y` is used. `%y` represents a 2-digit year, but Datix doesn't assume anything\n    about which *century* such year refers to. For this reason, the `:pivot_year`\n    option is required whenever `%y` is present in the format string; if not\n    present, this function returns `{:error, %Datix.OptionError{}}`.\n    For example, if `pivot_year: 65`, then the 2-digit year `64` and lower will\n    refer to the current century (`2064` and so on at the time of writing this),\n    while the 2-digit year `65` and higher will refer to the previous century\n    (`1965` and so on).\n\nMissing values will be set to minimum.","ref":"Datix.Date.html#parse/3-options"},{"type":"function","title":"Examples - Datix.Date.parse/3","doc":"iex> Datix.Date.parse(\"2022-05-11\", \"%x\")\n    {:ok, ~D[2022-05-11]}\n\n    iex> Datix.Date.parse(\"2021/01/10\", \"%Y/%m/%d\")\n    {:ok, ~D[2021-01-10]}\n\n    iex> format = Datix.compile!(\"%Y/%m/%d\")\n    iex> Datix.Date.parse(\"2021/01/10\", format)\n    {:ok, ~D[2021-01-10]}\n\n    iex> Datix.Date.parse(\"2021/01/10\", \"%x\", preferred_date: \"%Y/%m/%d\")\n    {:ok, ~D[2021-01-10]}\n\n    iex> Datix.Date.parse(\"18\", \"%y\", pivot_year: 50)\n    {:ok, ~D[2018-01-01]}\n\n    iex> Datix.Date.parse(\"18\", \"%y\", pivot_year: 15)\n    {:ok, ~D[1918-01-01]}\n\n    iex> Datix.Date.parse(\"18\", \"%y\")\n    {:error, %Datix.OptionError{reason: :missing, option: :pivot_year}}\n\n    iex> Datix.Date.parse(\"\", \"\")\n    {:ok, ~D[0000-01-01]}\n\n    iex> Datix.Date.parse(\"1736/13/03\", \"%Y/%m/%d\", calendar: Coptic)\n    {:ok, ~D[1736-13-03 Cldr.Calendar.Coptic]}\n\n    iex> Datix.Date.parse(\"Mi, 1.4.2020\", \"%a, %-d.%-m.%Y\",\n    ...>   abbreviated_day_of_week_names: ~w(Mo Di Mi Do Fr Sa So))\n    {:ok, ~D[2020-04-01]}\n\n    iex> Datix.Date.parse(\"Fr, 1.4.2020\", \"%a, %-d.%-m.%Y\",\n    ...>   abbreviated_day_of_week_names: ~w(Mo Di Mi Do Fr Sa So))\n    {:error, %Datix.ValidationError{reason: :invalid_date, module: Datix.Date}}","ref":"Datix.Date.html#parse/3-examples"},{"type":"function","title":"Datix.Date.parse!/3","doc":"Parses a date string according to the given `format`, erroring out for\ninvalid arguments.","ref":"Datix.Date.html#parse!/3"},{"type":"function","title":"Options - Datix.Date.parse!/3","doc":"Accepts the same options as listed for `parse/3`.","ref":"Datix.Date.html#parse!/3-options"},{"type":"module","title":"Datix.DateTime","doc":"A `DateTime` parser using `Calendar.strftime/3` format string.","ref":"Datix.DateTime.html"},{"type":"function","title":"Datix.DateTime.parse/3","doc":"Parses a datetime string into a `DateTime` according to the given `format`.\n\nSee the `Calendar.strftime/3` documentation for how to specify a format string.\n\nWhen the format string contains an offset (`%z`) or a timezone abbreviation (`%Z`),\nthen the `:time_zone` option is required. See below for more information on the option.","ref":"Datix.DateTime.html#parse/3"},{"type":"function","title":"Options - Datix.DateTime.parse/3","doc":"* `:calendar` - the calendar to build the `Date`, defaults to `Calendar.ISO`\n\n  * `:preferred_date` - a string for the preferred format to show dates,\n    it can't contain the `%x` format and defaults to `\"%Y-%m-%d\"`\n    if the option is not received\n\n  *  `:month_names` - a list of the month names, if the option is not received\n    it defaults to a list of month names in English\n\n  * `:abbreviated_month_names` - a list of abbreviated month names, if the\n    option is not received it defaults to a list of abbreviated month names in\n    English\n\n  * `:day_of_week_names` - a list of day names, if the option is not received\n    it defaults to a list of day names in English\n\n  * `:abbreviated_day_of_week_names` - a list of abbreviated day names, if the\n    option is not received it defaults to a list of abbreviated day names in\n    English\n\n  * `:preferred_time` - a string for the preferred format to show times,\n    it can't contain the `%X` format and defaults to `\"%H:%M:%S\"`\n    if the option is not received\n\n  * `:am_pm_names` - a keyword list with the names of the period of the day,\n    defaults to `[am: \"am\", pm: \"pm\"]`.\n\n  * `:pivot_year` - (since v0.2.0) a 2-digit year that represents the *pivot year* to use when\n    `%y` is used. `%y` represents a 2-digit year, but Datix doesn't assume anything\n    about which *century* such year refers to. For this reason, the `:pivot_year`\n    option is required whenever `%y` is present in the format string; if not\n    present, this function returns `{:error, :missing_pivot_year_option}`.\n    For example, if `pivot_year: 65`, then the 2-digit year `64` and lower will\n    refer to the current century (`2064` and so on at the time of writing this),\n    while the 2-digit year `65` and higher will refer to the previous century\n    (`1965` and so on).\n\n  * `:time_zone` - (since v0.3.0) a function that receives the parsed datetime as \n    `NaiveDateTime`, the zone abbreviation, and the offset to handle the time zone \n    and returns an `:ok` tuple with the `DateTime` or an `:error` tuple with \n    `Datix.ValidationError`. Defaults to a function handling only \"UTC\".","ref":"Datix.DateTime.html#parse/3-options"},{"type":"function","title":"Examples - Datix.DateTime.parse/3","doc":"iex> Datix.DateTime.parse(\"2021/01/10 12:14:24\", \"%Y/%m/%d %H:%M:%S\")\n    {:ok, ~U[2021-01-10 12:14:24Z]}\n\n    iex> format = Datix.compile!(\"%Y/%m/%d %H:%M:%S\")\n    iex> Datix.DateTime.parse(\"2021/01/10 12:14:24\", format)\n    {:ok, ~U[2021-01-10 12:14:24Z]}\n\n    iex> Datix.DateTime.parse(\"2018/06/27 11:23:55 CEST+0200\", \"%Y/%m/%d %H:%M:%S %Z%z\")\n    {:error, %Datix.ValidationError{module: Datix.DateTime, reason: {:unknown_timezone_abbr, \"CEST\"}}}\n\n\nIf you need to parse non-UTC datetimes, you'll have to pass the `:time_zone` option.\n\n    tz_fun = fn naive_datetime, abbr, offset ->\n      {:ok, naive_datetime |> DateTime.from_naive!(convert_abbr(abbr)) |> DateTime.add(-offset)}\n    end\n\n    Datix.DateTime.parse(\"2018/06/27 11:23:55 CEST+0200\", \"%Y/%m/%d %H:%M:%S %Z%z\", time_zone: tz_fun)","ref":"Datix.DateTime.html#parse/3-examples"},{"type":"function","title":"Datix.DateTime.parse!/3","doc":"Parses a datetime string according to the given `format`, erroring out for\ninvalid arguments.\n\nThis function is just defined for UTC datetimes.","ref":"Datix.DateTime.html#parse!/3"},{"type":"function","title":"Options - Datix.DateTime.parse!/3","doc":"Accepts the same options as listed for `parse/3`.","ref":"Datix.DateTime.html#parse!/3-options"},{"type":"function","title":"Examples - Datix.DateTime.parse!/3","doc":"iex> Datix.DateTime.parse!(\"2018/06/27 11:23:55 UTC+0000\", \"%Y/%m/%d %H:%M:%S %Z%z\")\n    ~U[2018-06-27 11:23:55Z]\n\n    iex> format = Datix.compile!(\"%Y/%m/%d %H:%M:%S %Z%z\")\n    iex> Datix.DateTime.parse!(\"2018/06/27 11:23:55 UTC+0000\", format)\n    ~U[2018-06-27 11:23:55Z]\n\n    iex> Datix.DateTime.parse!(\"2018/06/27 11:23:55 CEST+0200\", \"%Y/%m/%d %H:%M:%S %Z%z\")\n    ** (Datix.ValidationError) unknown timezone abbreviation: CEST","ref":"Datix.DateTime.html#parse!/3-examples"},{"type":"module","title":"Datix.NaiveDateTime","doc":"A `NaiveDateTime` parser using `Calendar.strftime/3` format-string.","ref":"Datix.NaiveDateTime.html"},{"type":"function","title":"Datix.NaiveDateTime.parse/3","doc":"Parses a datetime string into a `NaiveDateTime` according to the given `format`.\n\nSee the `Calendar.strftime/3` documentation for how to specify a format string.\n\n**Time zone information is ignored**.","ref":"Datix.NaiveDateTime.html#parse/3"},{"type":"function","title":"Options - Datix.NaiveDateTime.parse/3","doc":"* `:calendar` - the calendar to build the `Date`, defaults to `Calendar.ISO`\n\n  * `:preferred_date` - a string for the preferred format to show dates,\n    it can't contain the `%x` format and defaults to `\"%Y-%m-%d\"`\n    if the option is not received\n\n  *  `:month_names` - a list of the month names, if the option is not received\n    it defaults to a list of month names in English\n\n  * `:abbreviated_month_names` - a list of abbreviated month names, if the\n    option is not received it defaults to a list of abbreviated month names in\n    English\n\n  * `:day_of_week_names` - a list of day names, if the option is not received\n    it defaults to a list of day names in English\n\n  * `:abbreviated_day_of_week_names` - a list of abbreviated day names, if the\n    option is not received it defaults to a list of abbreviated day names in\n    English\n\n  * `:preferred_time` - a string for the preferred format to show times,\n    it can't contain the `%X` format and defaults to `\"%H:%M:%S\"`\n    if the option is not received\n\n  * `:am_pm_names` - a keyword list with the names of the period of the day,\n    defaults to `[am: \"am\", pm: \"pm\"]`.\n\n  * `:pivot_year` - a 2-digit year that represents the *pivot year* to use when\n    `%y` is used. `%y` represents a 2-digit year, but Datix doesn't assume anything\n    about which *century* such year refers to. For this reason, the `:pivot_year`\n    option is required whenever `%y` is present in the format string; if not\n    present, this function returns `{:error, :missing_pivot_year_option}`.\n    For example, if `pivot_year: 65`, then the 2-digit year `64` and lower will\n    refer to the current century (`2064` and so on at the time of writing this),\n    while the 2-digit year `65` and higher will refer to the previous century\n    (`1965` and so on).","ref":"Datix.NaiveDateTime.html#parse/3-options"},{"type":"function","title":"Examples - Datix.NaiveDateTime.parse/3","doc":"iex> Datix.NaiveDateTime.parse(\"2021/01/10 12:14:24\", \"%Y/%m/%d %H:%M:%S\")\n    {:ok, ~N[2021-01-10 12:14:24]}\n\n    iex> format = Datix.compile!(\"%Y/%m/%d %H:%M:%S\")\n    iex> Datix.NaiveDateTime.parse(\"2021/01/10 12:14:24\", format)\n    {:ok, ~N[2021-01-10 12:14:24]}\n\n    iex> Datix.NaiveDateTime.parse(\"2018/06/27 11:23:55 CEST+0200\", \"%Y/%m/%d %H:%M:%S %Z%z\")\n    {:ok, ~N[2018-06-27 11:23:55Z]}\n\n    iex> Datix.NaiveDateTime.parse(\"21/11/22\", \"%y/%m/%d\", pivot_year: 50)\n    {:ok, ~N[2021-11-22 00:00:00]}\n\n    iex> Datix.NaiveDateTime.parse(\"21/11/22\", \"%y/%m/%d\", pivot_year: 20)\n    {:ok, ~N[1921-11-22 00:00:00]}","ref":"Datix.NaiveDateTime.html#parse/3-examples"},{"type":"function","title":"Datix.NaiveDateTime.parse!/3","doc":"Parses a datetime string according to the given `format`, erroring out for\ninvalid arguments.","ref":"Datix.NaiveDateTime.html#parse!/3"},{"type":"function","title":"Options - Datix.NaiveDateTime.parse!/3","doc":"Accepts the same options as listed for `parse/3`.","ref":"Datix.NaiveDateTime.html#parse!/3-options"},{"type":"module","title":"Datix.Time","doc":"A `Time` parser using `Calendar.strftime/3` format-string.","ref":"Datix.Time.html"},{"type":"function","title":"Datix.Time.parse/3","doc":"Parses a time string according to the given `format`.\n\nSee the `Calendar.strftime/3` documentation for how to specify a format string.","ref":"Datix.Time.html#parse/3"},{"type":"function","title":"Options - Datix.Time.parse/3","doc":"* `:calendar` - the calendar to build the `Time`, defaults to `Calendar.ISO`\n\n  * `:preferred_time` - a string for the preferred format to show times,\n    it can't contain the `%X` format and defaults to `\"%H:%M:%S\"`\n    if the option is not received\n\n  * `:am_pm_names` - a keyword list with the names of the period of the day,\n    defaults to `[am: \"am\", pm: \"pm\"]`.\n\nMissing values will be set to minimum.","ref":"Datix.Time.html#parse/3-options"},{"type":"function","title":"Examples - Datix.Time.parse/3","doc":"iex> Datix.Time.parse(\"11:12:55\", \"%X\")\n    {:ok, ~T[11:12:55]}\n\n    iex> format = Datix.compile!(\"%X\")\n    iex> Datix.Time.parse(\"11:12:55\", format)\n    {:ok, ~T[11:12:55]}\n\n    iex> Datix.Time.parse(\"10 PM\", \"%I %p\")\n    {:ok, ~T[22:00:00]}","ref":"Datix.Time.html#parse/3-examples"},{"type":"function","title":"Datix.Time.parse!/3","doc":"Parses a date string according to the given `format`, erroring out for\ninvalid arguments.","ref":"Datix.Time.html#parse!/3"},{"type":"function","title":"Options - Datix.Time.parse!/3","doc":"Accepts the same options as listed for `parse/3`.","ref":"Datix.Time.html#parse!/3-options"},{"type":"exception","title":"Datix.FormatStringError","doc":"An exception for when the format string is invalid.","ref":"Datix.FormatStringError.html"},{"type":"type","title":"Datix.FormatStringError.reason/0","doc":"","ref":"Datix.FormatStringError.html#t:reason/0"},{"type":"type","title":"Datix.FormatStringError.t/0","doc":"","ref":"Datix.FormatStringError.html#t:t/0"},{"type":"exception","title":"Datix.OptionError","doc":"An exception that represents an error with some options.","ref":"Datix.OptionError.html"},{"type":"type","title":"Datix.OptionError.reason/0","doc":"","ref":"Datix.OptionError.html#t:reason/0"},{"type":"type","title":"Datix.OptionError.t/0","doc":"","ref":"Datix.OptionError.html#t:t/0"},{"type":"exception","title":"Datix.ParseError","doc":"An exception for when there is an error parsing a string.","ref":"Datix.ParseError.html"},{"type":"type","title":"Datix.ParseError.reason/0","doc":"","ref":"Datix.ParseError.html#t:reason/0"},{"type":"type","title":"Datix.ParseError.t/0","doc":"","ref":"Datix.ParseError.html#t:t/0"},{"type":"exception","title":"Datix.ValidationError","doc":"An exception for when a date or time fails validation.\n\nAn \"invalid\" date or time is a date or time that gets parsed correctly,\nbut that is semantically invalid. For example, a date with a day of `99`\nis invalid.","ref":"Datix.ValidationError.html"},{"type":"type","title":"Datix.ValidationError.reason/0","doc":"","ref":"Datix.ValidationError.html#t:reason/0"},{"type":"type","title":"Datix.ValidationError.t/0","doc":"","ref":"Datix.ValidationError.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}